# Ingenii Azure Data Platform (Python Package)

## Overview

This python package has config loaders, schema validators and helper functions needed by the Azure Data Platform Pulumi solution.

## TODOS
- [ ] Improve the documentation for this repo
- [ ] Add readme file for the python package
- [ ] Add tests
- [ ] Add makefile for easier interaction
- [ ] Add a build/test only GitHub workflow